@@ -1,6 +1,4 @@
 #line 2 "edit-distance.c.tmpl"
-#include <string.h>
-#include <stdio.h>
 /* For INT_MAX/INT_MIN */
 #include <limits.h>
 /* For malloc. */
@@ -9,7 +7,7 @@
 #include "config.h"
 #include "text-fuzzy.h"
 #include "edit-distance-char-trans.h"
-#line 14 "edit-distance.c.tmpl"
+#line 12 "edit-distance.c.tmpl"
 
 
 /* Our unsorted dictionary linked list.       */
@@ -95,12 +93,12 @@ int distance_char_trans (
                     text_fuzzy_t * tf)
 
 {
-#line 99 "edit-distance.c.tmpl"
+#line 97 "edit-distance.c.tmpl"
 
 
 
 
-#line 110 "edit-distance.c.tmpl"
+#line 108 "edit-distance.c.tmpl"
     const unsigned char * word1 = (const unsigned char *) tf->b.text;
     int len1 = tf->b.length;
     const unsigned char * word2 = (const unsigned char *) tf->text.text;
@@ -197,6 +195,6 @@ int distance_char_trans (
 
 #endif
 
-#line 372 "edit-distance.c.tmpl"
+#line 370 "edit-distance.c.tmpl"
 }
 
