@@ -1,6 +1,4 @@
 #line 2 "edit-distance.c.tmpl"
-#include <string.h>
-#include <stdio.h>
 /* For INT_MAX/INT_MIN */
 #include <limits.h>
 /* For malloc. */
@@ -14,18 +12,18 @@ int distance_char (
                     text_fuzzy_t * tf)
 
 {
-#line 99 "edit-distance.c.tmpl"
+#line 97 "edit-distance.c.tmpl"
 
 
 
 
-#line 110 "edit-distance.c.tmpl"
+#line 108 "edit-distance.c.tmpl"
     const unsigned char * word1 = (const unsigned char *) tf->b.text;
     int len1 = tf->b.length;
     const unsigned char * word2 = (const unsigned char *) tf->text.text;
     int len2 = tf->text.length;
 
-#line 209 "edit-distance.c.tmpl"
+#line 207 "edit-distance.c.tmpl"
 
     /* Matrix is the dynamic programming matrix. We economize on space
        by having only two columns. */
@@ -40,11 +38,11 @@ int distance_char (
     int j;
     int large_value;
 
-#line 225 "edit-distance.c.tmpl"
+#line 223 "edit-distance.c.tmpl"
     int max;
 
     max = tf->max_distance;
-#line 230 "edit-distance.c.tmpl"
+#line 228 "edit-distance.c.tmpl"
 
 #ifndef __GNUC__
     for (i = 0; i < 2; i++) {
@@ -185,6 +183,6 @@ int distance_char (
     return d;
 #endif
 
-#line 372 "edit-distance.c.tmpl"
+#line 370 "edit-distance.c.tmpl"
 }
 
